// qmidinetAbout.h
//
/****************************************************************************
   Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved.

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License
   as published by the Free Software Foundation; either version 2
   of the License, or (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

*****************************************************************************/

#ifndef __qmidinetAbout_h
#define __qmidinetAbout_h

#include "config.h"

#define QMIDINET_TITLE        PACKAGE_NAME

#define QMIDINET_SUBTITLE     "A MIDI Network Gateway via UDP/IP Multicast"
#define QMIDINET_WEBSITE      "https://qmidinet.sourceforge.io"
#define QMIDINET_COPYRIGHT    "Copyright (C) 2010-2019, rncbc aka Rui Nuno Capela. All rights reserved."

#define QMIDINET_DOMAIN       "rncbc.org"

#endif  // __qmidinetAbout_h

// end of qmidinetAbout.h

